/srv/mercurial-server/detachablepurple: 1bd5f2b5360d: Type and c...

Gilles Bedel gillux at cpw.pidgin.im
Fri Jun 15 22:01:36 EDT 2012


Changeset: 1bd5f2b5360d2f1ccf4b49d4e1bb6525752d22da
Author:	 Gilles Bedel <gillux at cpw.pidgin.im>
Date:	 2012-05-15 03:20 +0000
Branch:	 cpw.gillux.detachablepurple
URL: http://hg.pidgin.im/srv/mercurial-server/detachablepurple/rev/1bd5f2b5360d

Description:

Type and cast fixes.

diffstat:

 libpurple/dbus-server.c |   6 +++---
 libpurple/dbus-server.h |  12 ++++++------
 libpurple/pobject.c     |   4 ++--
 3 files changed, 11 insertions(+), 11 deletions(-)

diffs (82 lines):

diff --git a/libpurple/dbus-server.c b/libpurple/dbus-server.c
--- a/libpurple/dbus-server.c
+++ b/libpurple/dbus-server.c
@@ -503,12 +503,12 @@
 }
 
 void
-purple_dbus_assoc_gobject(const gchar *dbus_path, GObject *gobj)
+purple_dbus_assoc_gobject(const gchar *dbus_path, gpointer obj)
 {
 	g_return_if_fail(dbus_path_gobjects != NULL);
 	g_return_if_fail(dbus_path != NULL);
 
-	g_hash_table_insert(dbus_path_gobjects, g_strdup(dbus_path), gobj);
+	g_hash_table_insert(dbus_path_gobjects, g_strdup(dbus_path), obj);
 }
 
 void
@@ -520,7 +520,7 @@
 	g_hash_table_remove(dbus_path_gobjects, dbus_path);
 }
 
-GObject*
+gpointer
 purple_dbus_get_gobject_by_path(const gchar *dbus_path)
 {
 	g_return_val_if_fail(dbus_path_gobjects != NULL, NULL);
diff --git a/libpurple/pobject.c b/libpurple/pobject.c
--- a/libpurple/pobject.c
+++ b/libpurple/pobject.c
@@ -140,14 +140,14 @@
 static void
 g_value_dbus_path2gobject(const GValue *src, GValue *dest)
 {
-	GObject *obj = NULL;
+	gpointer obj = NULL;
 	gchar *path_name;
 
 	path_name = g_value_get_string(src);
 	if (path_name && path_name[0] != '\0') {
 		obj = purple_dbus_get_gobject_by_path(path_name);
 	}
-	g_value_set_object(dest, obj);
+	g_value_set_object(dest, G_OBJECT(obj));
 }
 
 /**



More information about the Commits mailing list
diff --git a/libpurple/dbus-server.h b/libpurple/dbus-server.h
--- a/libpurple/dbus-server.h
+++ b/libpurple/dbus-server.h
@@ -224,12 +224,12 @@
 gchar* purple_dbus_sanitize_dbus_path(const gchar *str);
 
 /**
  * Associates a local GObject with its matching remote dbus path.
  *
  * @param dbus_path The dbus path name.
- * @param dbus_path The GObject.
+ * @param object The object.
  */
-void purple_dbus_assoc_gobject(const gchar *dbus_path, GObject *gobj);
+void purple_dbus_assoc_gobject(const gchar *dbus_path, gpointer object);
 
 /**
  * Disassociates a local GObject with its matching remote dbus path.
@@ -240,12 +240,12 @@
 void purple_dbus_disassoc_gobject(const gchar *dbus_path);
 
 /**
  * Get the local GObject associated with the given dbus path.
  *
  * @param dbus_path The dbus path name.
  * @return The local GObject.
  */
-GObject* purple_dbus_get_gobject_by_path(const gchar *dbus_path);
+gpointer purple_dbus_get_gobject_by_path(const gchar *dbus_path);
 
 /**
 
@@ -224,12 +224,12 @@
 
 /**
- * Associates a local GObject with its matching remote dbus path.
+ * Associates a local object with its matching remote dbus path.
  *
  * @param dbus_path The dbus path name.
@@ -240,12 +240,12 @@
 
 /**
- * Get the local GObject associated with the given dbus path.
+ * Get the local object associated with the given dbus path.
  *
  * @param dbus_path The dbus path name.
@@ -240,12 +240,12 @@
  *
  * @param dbus_path The dbus path name.
- * @return The local GObject.
+ * @return The local object.
  */